# nsgpytorch

Non-stationary GP models implemented based on [GPyTorch](https://gpytorch.ai/).

## Installation
```bash
pip install nsgpytorch
```

## Current list of models
* [Latent Lengthscale Model by Plagemann et al.](http://ais.informatik.uni-freiburg.de/publications/papers/plagemann08ecml.pdf)